package com.zy.omp.controller.wx;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.zy.omp.common.ServerResponse;
import com.zy.omp.common.controller.BaseController;
import com.zy.omp.model.Device;
import com.zy.omp.model.Relation;
import com.zy.omp.service.DeviceService;
import com.zy.omp.service.RelationService;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 用户设备绑定关系
 *
 * @author chen_yi
 * Create on 2020/8/1
 */
@RestController
@RequestMapping("omp/api/wx/relation")
public class RelationController extends BaseController {

    @Resource
    private RelationService relationService;
    @Resource
    private DeviceService deviceService;

    /**
     * 更新设备名称
     */
    @PostMapping("updateName.do")
    public ServerResponse updateName(Relation relation) {
        relationService.update(new UpdateWrapper<Relation>()
                .set("deviceName", relation.getDeviceName())
                .eq("openId", getOpenId())
                .eq("openNum", relation.getOpenNum()));
        return ServerResponse.createBySuccess();
    }

    /**
     * 添加绑定关系
     */
    @PostMapping("bind.do")
    public ServerResponse bind(Relation relation) {
        //校验设备码有效性
        if (deviceService.getOne(new QueryWrapper<Device>().eq("openNum", relation.getOpenNum())) == null)
            return ServerResponse.createByWarning("设备码无效!");
        //校验是否有绑定关系
        if (relationService.checkBind(relation.getOpenNum()))
            return ServerResponse.createByWarning("该设备已经有用户绑定!");
        relation.setOpenId(getOpenId());
        relationService.save(relation);
        return ServerResponse.createBySuccess();
    }

    /**
     * 解除绑定关系
     */
    @PostMapping("unbind.do")
    public ServerResponse unbind(String openNum) {
        relationService.remove(new QueryWrapper<Relation>()
                .eq("openNum", openNum)
                .eq("openId", getOpenId()));
        return ServerResponse.createBySuccess();
    }

}
